Class: VirusTotal::Application

Inherits:
Object
  • Object
show all
Defined in:
lib/virustotal/application.rb

Instance Method Summary collapse

Constructor Details

#initializeApplication

Creates a new instance of the [Application] class



8
9
10
11
12
13
14
15
# File 'lib/virustotal/application.rb', line 8

def initialize
  @options = {}
  @config = {}
  @hashes = Array.new
  @files_of_hashes = Array.new
  @sites = Array.new
  @uploads = Array.new
end

Instance Method Details

#load_configObject

Loads the .virustotal config file for the api key



121
122
123
124
125
126
127
128
# File 'lib/virustotal/application.rb', line 121

def load_config
  if File.exists?(File.expand_path(CONFIG_FILE))
    @config = YAML.load_file File.expand_path(CONFIG_FILE)
  else
    puts "[!] #{CONFIG_FILE} does not exist. Please run virustotal --create-config, to create it."
    exit
  end
end

#parse_options(args) ⇒ Hash

Parses the command the line options and returns the parsed options hash

Returns:

  • (Hash)

    of the parsed options



20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/virustotal/application.rb', line 20

def parse_options(args)
  begin
    @options['output'] = :stdout
    @options['debug'] = false
    
    opt = OptionParser.new do |opt|
      opt.banner = "#{APP_NAME} v#{VERSION}\nJacob Hammack\nhttp://www.hammackj.com\n\n"
      opt.banner << "Usage: #{APP_NAME} <options>"
      opt.separator('')
      opt.separator("Search Options")
    
      opt.on('-h HASH', '--search-hash HASH', 'Searches a single hash on virustotal.com') { |hash| 
        @hashes.push(hash)
      }

      opt.on('-f FILE', '--search-file FILE', 'Searches a each hash in a file of hashes on virustotal.com') { |file|
        if File.exists?(file)
          puts "[+] Adding file #{file}" if @options["debug"]
          @files_of_hashes.push(file)
        else
          puts "[!] #{file} does not exist, please check your input!\n"
        end
      }
      
      opt.on('-u FILE', '--upload-file FILE', 'Uploads a file to virustotal.com for analysis') do |file|
        if File.exists?(file)
          puts "[+] Adding file #{file}" if @options["debug"]
          @uploads.push(file)
        else
          puts "[!] #{file} does not exist, please check your input!\n"
        end
      end

      opt.on('-s SITE', '--search-site SITE', 'Searches for a single url on virustotal.com') { |site| 
        @sites.push(site)
      }      
        
      opt.separator('')
      opt.separator('Output Options')

      opt.on('-x', '--xml-output', 'Print results as xml to stdout') { 
        @options["output"] = :xml
      }
  
      opt.on('-y', '--yaml-output', 'Print results as yaml to stdout') {
        @options['output'] = :yaml
      }
      
      opt.on('--stdout-output', 'Print results as normal text line to stdout, this is default') {
        @options['output'] = :stdout
      }

      opt.separator ''
      opt.separator 'Advanced Options'

      opt.on('-c', '--create-config', 'Creates a skeleton config file to use') do          
        if File.exists?(File.expand_path(CONFIG_FILE)) == false
          File.open(File.expand_path(CONFIG_FILE), 'w+') do |f| 
            f.write("virustotal: \n  api-key: \n  timeout: 10\n\n") 
          end

          puts "[*] An empty #{File.expand_path(CONFIG_FILE)} has been created. Please edit and fill in the correct values."
          exit
        else
          puts "[!]  #{File.expand_path(CONFIG_FILE)} already exists. Please delete it if you wish to re-create it."
          exit
        end
      end

      opt.on('-d', '--debug', 'Print verbose debug information') do |d|
        @options["debug"] = d
      end
    
      opt.separator ''
      opt.separator 'Other Options'
    
      opt.on('-v', '--version', "Shows application version information") do
        puts "#{APP_NAME} - #{VERSION}"
        exit
      end

      opt.on_tail("-?", "--help", "Show this message") { |help|
        puts opt.to_s + "\n"
        exit
      } 
    end
          
    if ARGV.length != 0 
      opt.parse!
    else
      puts opt.to_s + "\n"
      exit
    end   
  rescue OptionParser::MissingArgument => m
    puts opt.to_s + "\n"
    exit
  end
end

#run(args) ⇒ Object

Processes all of the command line arguments and displays the results



132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/virustotal/application.rb', line 132

def run(args)
  parse_options(args)    
  load_config
  
  vt = VirusTotal.new(@config["virustotal"]["api-key"], @config["virustotal"]["timeout"], @options["debug"])
  
  if @options['output'] == :stdout
    output_method = :to_stdout
  elsif @options['output'] == :yaml
    output_method = :to_yaml
  elsif @options['output'] == :xml
    output_method = :to_xml
    print "<results>\n"
  end
        
  if @files_of_hashes != nil
    @files_of_hashes.each do |file|
      f = File.open(file, 'r')

      f.each do |hash|
        hash.chomp!
        @hashes.push hash
      end
    end
  end    
        
  if @hashes != nil
    @hashes.each do |hash|
      result = vt.query_hash hash          
      print result.send output_method
    end
  end
  
  if @sites != nil
    @sites.each do |site|
      result = vt.query_site site
      print result.send output_method
    end
  end
  
  if @uploads != nil
    @uploads.each do |upload|
      result = vt.query_upload upload
      print result.send output_method
    end
  end
  
  if @options['output'] == :xml
    print "</results>\n"
  end
end